/*
 * Copyright (c) 2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: FileMenu.java,v 1.2 2006/11/20 18:35:08 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.file.gui;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import edu.indiana.extreme.xbaya.XBayaEngine;

/**
 * @author Satoshi Shirasuna
 */
public class FileMenu {

    private JMenu fileMenu;

    private WorkflowFiler graphFiler;

    private JythonFiler jythonFiler;

    private ImageFiler imageFiler;

    private BPELFiler bpelFiler;

    private JMenuItem openWorkflowItem;

    private JMenuItem saveWorkflowItem;

    private JMenuItem exportJythonItem;

    private JMenuItem exportBpelItem;

    private JMenuItem saveImageItem;

    private JMenuItem importWorkflowItem;

    /**
     * Constructs a FileMenu.
     * 
     * @param engine
     * 
     */
    public FileMenu(XBayaEngine engine) {
        this.graphFiler = new WorkflowFiler(engine);
        this.jythonFiler = new JythonFiler(engine);
        this.imageFiler = new ImageFiler(engine);
        this.bpelFiler = new BPELFiler(engine);

        createFileMenu();
    }

    private void createFileMenu() {

        createOpenWorkflowMenuItem();
        createSaveWorkflowItem();
        createImportWorkflowItem();
        createExportJythonScriptItem();
        createExportBpelScriptItem();
        createSaveWorkflowImageItem();

        this.fileMenu = new JMenu("File");
        this.fileMenu.setMnemonic(KeyEvent.VK_F);

        this.fileMenu.add(this.openWorkflowItem);
        this.fileMenu.add(this.saveWorkflowItem);
        this.fileMenu.addSeparator();
        this.fileMenu.add(this.importWorkflowItem);
        this.fileMenu.addSeparator();
        this.fileMenu.add(this.exportJythonItem);
        this.fileMenu.add(this.exportBpelItem);
        this.fileMenu.addSeparator();
        this.fileMenu.add(this.saveImageItem);
    }

    /**
     * @return The file menu.
     */
    public JMenu getMenu() {
        return this.fileMenu;
    }

    private void createOpenWorkflowMenuItem() {
        this.openWorkflowItem = new JMenuItem("Open Workflow");
        this.openWorkflowItem.setMnemonic(KeyEvent.VK_O);
        this.openWorkflowItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent event) {
                FileMenu.this.graphFiler.openWorkflow();
            }
        });
    }

    private void createSaveWorkflowItem() {
        this.saveWorkflowItem = new JMenuItem("Save Workflow");
        this.saveWorkflowItem.setMnemonic(KeyEvent.VK_S);
        this.saveWorkflowItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                FileMenu.this.graphFiler.saveWorkflow();
            }
        });
    }

    private void createImportWorkflowItem() {
        this.importWorkflowItem = new JMenuItem("Import Workflow");
        this.importWorkflowItem.setMnemonic(KeyEvent.VK_I);
        this.importWorkflowItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                FileMenu.this.graphFiler.importWorkflow();
            }
        });
    }

    private void createExportJythonScriptItem() {
        this.exportJythonItem = new JMenuItem("Export WS Jython Script");
        this.exportJythonItem.setMnemonic(KeyEvent.VK_J);
        this.exportJythonItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                FileMenu.this.jythonFiler.exportJythonScript();
            }
        });
    }

    private void createExportBpelScriptItem() {
        this.exportBpelItem = new JMenuItem("Export BPEL Script");
        this.exportBpelItem.setMnemonic(KeyEvent.VK_B);
        this.exportBpelItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                FileMenu.this.bpelFiler.exportBPEL();
            }
        });
    }

    private void createSaveWorkflowImageItem() {
        this.saveImageItem = new JMenuItem("Save Workflow Image");
        this.saveImageItem.setMnemonic(KeyEvent.VK_I);
        this.saveImageItem.addActionListener(new AbstractAction() {
            public void actionPerformed(ActionEvent e) {
                FileMenu.this.imageFiler.saveWorkflowImage();
            }
        });
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
